@@ -20,7 +20,7 @@ public:
     void setShowOffType(bool newShowOffType);
 
 protected:
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    [[nodiscard]] bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 Q_SIGNALS:
     void showOffTypeChanged();
